==> kubernetes-model-1.0.16-sources.jar: annotations/io/fabric8/kubernetes/api/model/EnvVarSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class EnvVarSourceBuilder extends EnvVarSourceFluent<EnvVarSourceBuilder> implements VisitableBuilder<EnvVarSource,EnvVarSourceBuilder>{

     EnvVarSourceFluent<?> fluent;
public EnvVarSourceBuilder(){
    this(new EnvVarSource());
}
public EnvVarSourceBuilder( EnvVarSourceFluent<?> fluent ){
    this(fluent, new EnvVarSource());
}
public EnvVarSourceBuilder( EnvVarSourceFluent<?> fluent , EnvVarSource instance ){
    this.fluent = fluent; fluent.withFieldRef(instance.getFieldRef()); 
}
public EnvVarSourceBuilder( EnvVarSource instance ){
    this.fluent = this; this.withFieldRef(instance.getFieldRef()); 
}

public EditableEnvVarSource build(){
    EditableEnvVarSource buildable = new EditableEnvVarSource(fluent.getFieldRef());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
EnvVarSourceBuilder that = (EnvVarSourceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.49-sources.jar: annotations/io/fabric8/kubernetes/api/model/EnvVarSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class EnvVarSourceBuilder extends EnvVarSourceFluentImpl<EnvVarSourceBuilder> implements VisitableBuilder<EnvVarSource,EnvVarSourceBuilder>{

     EnvVarSourceFluent<?> fluent;
public EnvVarSourceBuilder(){
    this(new EnvVarSource());
}
public EnvVarSourceBuilder( EnvVarSourceFluent<?> fluent ){
    this(fluent, new EnvVarSource());
}
public EnvVarSourceBuilder( EnvVarSourceFluent<?> fluent , EnvVarSource instance ){
    this.fluent = fluent; fluent.withConfigMapKeyRef(instance.getConfigMapKeyRef()); fluent.withFieldRef(instance.getFieldRef()); fluent.withSecretKeyRef(instance.getSecretKeyRef()); 
}
public EnvVarSourceBuilder( EnvVarSource instance ){
    this.fluent = this; this.withConfigMapKeyRef(instance.getConfigMapKeyRef()); this.withFieldRef(instance.getFieldRef()); this.withSecretKeyRef(instance.getSecretKeyRef()); 
}

public EditableEnvVarSource build(){
    EditableEnvVarSource buildable = new EditableEnvVarSource(fluent.getConfigMapKeyRef(),fluent.getFieldRef(),fluent.getSecretKeyRef());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
EnvVarSourceBuilder that = (EnvVarSourceBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
